$debug
--------------------------------------------------------------------------------
-- This module declares renaming rules for incoming uploaded files.
--
-- The format of an entry is: 
-- { pattern="[pattern]", target="[file_name]", func=[ref_to_function] }
--
-- <root_dir> points to the path where the files should be saved, and
-- is always required in the table
--------------------------------------------------------------------------------


--------------------------------------------------------------------------------
-- Default rules table for uploaded files
--------------------------------------------------------------------------------
cgilua.uploadrules = {
  { pattern="(.*)%.doc", target="upload%.%1%.doc"},
  { pattern="(.*)%.bmp", target="upload%.%1%.bmp"},
  ; root_dir = "c:/temp/"
}


--------------------------------------------------------------------------------
-- Auxiliar functions to create new filenames when uploading (example)
---
-- The only requirement for functions used for this purpose is that
-- they must return a string containing the new filename for the file 
-- being transferred.
--------------------------------------------------------------------------------

--------------------------------------------------------------------------------
-- This function adds the current date to the end of the prefix of the file name
--------------------------------------------------------------------------------
function AddDate(prefix, sufix)
   prefix = prefix..date("%d%m%Y")
   return prefix.."."..sufix
end

--------------------------------------------------------------------------------
-- This function changes the sufix of the file name to a integer counter. 
-- This counter should be stored in a file "files.count" located in the 
-- root_dir directory
--------------------------------------------------------------------------------
function AddCounter(prefix)
   dofile(rules.root_dir.."files.count")
   local filename = prefix.."."..tostring(i)
   
   writeto(rules.root_dir.."files.count")
   write("i="..tostring(i+1))
   writeto()
   
   return filename
end


--------------------------------------------------------------------------------
-- Example of an alternative rules table (must be a global variable!).
-- This is a rule table that is used only if the HTML form has an entry like:
-- <input type="hidden" name="rules_arq1" value="upload_example2">
-- <input type="file" name="arq1">
--------------------------------------------------------------------------------
upload_example2 = {
  { pattern="(.*)%.doc", target="%1%.docteste"},
  { pattern="(.*)%..*", target="%1", func=AddCounter};                        
  root_dir = "c:/temp/"
}

